Tests
=====

Unit tests can be run with ``py.test`` and coverage tests with ``tox``::

   make tests
   make tests-coverage
   make lint
   make clean


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
